# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dialogo.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets
import sys
from PyQt5.QtGui import *
from PyQt5.QtCore import *
from PyQt5.QtWidgets import *
from PyQt5.QtWidgets import QInputDialog, QLineEdit, QDialog,QWidget, QPushButton, QDialog, QApplication
from PyQt5.QtCore import pyqtSlot
from PyQt5.QtGui import QPainter, QPen
from PyQt5.Qt import Qt
from libs.linea import DibujarLineaApp

class Ui_Dialog1(object):
    genera = False

    def setupUi1(self, Ui_Dialog):
        Ui_Dialog.setObjectName("Dialog")
        Ui_Dialog.resize(498, 488)
        # Esto hay que añadirlo para luego poder cerrar el dialogo
        self.dialog = Ui_Dialog
        self.buttonBox = QtWidgets.QDialogButtonBox(Ui_Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(300, 440, 171, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")

        self.label = QtWidgets.QLabel(Ui_Dialog)
        self.label.setGeometry(QtCore.QRect(20, 20, 431, 17))
        self.label.setObjectName("label")

        self.escala = QtWidgets.QLineEdit(Ui_Dialog)
        self.escala.setGeometry(QtCore.QRect(20, 70, 113, 25))
        self.escala.setObjectName("lineEdit")

        self.medidas = QtWidgets.QComboBox(Ui_Dialog)
        self.medidas.setGeometry(QtCore.QRect(150, 70, 51, 25))
        self.medidas.setObjectName("comboBox")
        self.medidas.addItem("")
        self.medidas.addItem("")
        self.medidas.addItem("")

        self.line = QtWidgets.QFrame(Ui_Dialog)
        self.line.setGeometry(QtCore.QRect(0, 110, 491, 20))
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.label_3 = QtWidgets.QLabel(Ui_Dialog)
        self.label_3.setGeometry(QtCore.QRect(20, 140, 391, 17))
        self.label_3.setObjectName("label_3")
        self.checkBox = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox.setEnabled(False)
        self.checkBox.setGeometry(QtCore.QRect(30, 180, 151, 23))
        self.checkBox.setChecked(True)
        self.checkBox.setObjectName("checkBox")
        self.checkBox_2 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_2.setGeometry(QtCore.QRect(30, 220, 161, 23))
        self.checkBox_2.setObjectName("checkBox_2")
        self.checkBox_3 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_3.setGeometry(QtCore.QRect(30, 260, 131, 24))
        self.checkBox_3.setObjectName("checkBox_3")
        self.checkBox_4 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_4.setGeometry(QtCore.QRect(250, 260, 131, 23))
        self.checkBox_4.setObjectName("checkBox_4")
        self.checkBox_5 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_5.setGeometry(QtCore.QRect(250, 220, 211, 23))
        self.checkBox_5.setObjectName("checkBox_5")
        self.checkBox_6 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_6.setGeometry(QtCore.QRect(250, 180, 221, 23))
        self.checkBox_6.setObjectName("checkBox_6")
        self.checkBox_7 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_7.setGeometry(QtCore.QRect(30, 360, 231, 23))
        self.checkBox_7.setObjectName("checkBox_7")
        self.checkBox_8 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_8.setGeometry(QtCore.QRect(30, 400, 171, 23))
        self.checkBox_8.setObjectName("checkBox_8")
        self.checkBox_9 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_9.setGeometry(QtCore.QRect(250, 360, 161, 23))
        self.checkBox_9.setObjectName("checkBox_9")
        self.checkBox_10 = QtWidgets.QCheckBox(Ui_Dialog)
        self.checkBox_10.setGeometry(QtCore.QRect(250, 400, 231, 23))
        self.checkBox_10.setObjectName("checkBox_10")
        self.label_4 = QtWidgets.QLabel(Ui_Dialog)
        self.label_4.setGeometry(QtCore.QRect(20, 330, 431, 20))
        self.label_4.setObjectName("label_4")
        self.line_2 = QtWidgets.QFrame(Ui_Dialog)
        self.line_2.setGeometry(QtCore.QRect(0, 310, 491, 16))
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        # Aquí se conecta el botón de Ok con la funcionalidad que quieres.
        # En concreto, el método de actualizar que se define luego.
        self.buttonBox.accepted.connect(self.actualizar1)
        self.retranslateUi1(Ui_Dialog)
        QtCore.QMetaObject.connectSlotsByName(Ui_Dialog)


    def retranslateUi1(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.label.setText(_translate("Dialog", "Enter the scale and the corresponding unit:"))
        self.medidas.setItemText(0, _translate("Dialog", "cm"))
        self.medidas.setItemText(1, _translate("Dialog", "mm"))
        self.medidas.setItemText(2, _translate("Dialog", "µm"))
        #self.label_2.setText(_translate("Dialog", "px"))
        self.label_3.setText(_translate("Dialog", "Select the excel columns:"))
        self.checkBox.setText(_translate("Dialog", "Name of the image"))
        self.checkBox_2.setText(_translate("Dialog", "Number os stomata"))
        self.checkBox_3.setText(_translate("Dialog", "Average height"))
        self.checkBox_4.setText(_translate("Dialog", "Width average"))
        self.checkBox_5.setText(_translate("Dialog", "Typical deviation of height"))
        self.checkBox_6.setText(_translate("Dialog", "Typical deviation of the width"))
        self.checkBox_7.setText(_translate("Dialog", "Number stomata per surface"))
        self.checkBox_8.setText(_translate("Dialog", "Area of ​​surface"))
        self.checkBox_9.setText(_translate("Dialog", "Stomata by surface"))
        self.checkBox_10.setText(_translate("Dialog", "Height/width of each stoma"))
        self.label_4.setText(_translate("Dialog", "If you do not have a surface, the columns will be empty"))



    def actualizar1(self):
        self.genera = True
        # Se lee el valor de la caja de texto
        try:
            escalas = int(self.escala.text())

            #pixeles = int(self.pixel.text())
            #miramos cual es la medida seleccionado en el combo box
            unidad = self.medidas.currentText()
            #ahora miramos el resultado de los checkBox
            ch2 = self.checkBox_2.isChecked()
            ch3 = self.checkBox_3.isChecked()
            ch4 = self.checkBox_4.isChecked()
            ch5 = self.checkBox_5.isChecked()
            ch6 = self.checkBox_6.isChecked()
            ch7 = self.checkBox_7.isChecked()
            ch8 = self.checkBox_8.isChecked()
            ch9 = self.checkBox_9.isChecked()
            ch10 = self.checkBox_10.isChecked()
            # Se almacena dicho valor para poder usarlo desde el principal.
            # Antes de nada comprobamos que tento la escala como el pixel son numeros
            # if self.escalas.setValidator(QtGui.QDoubleValidator()):
            self.esca = escalas
            # else:
            #     QtGui.QMessageBox.about(self, "The scale must be a number")
            # if self.pixeles.setValidator(QtGui.QDoubleValidator()):
            #self.pix = pixeles
            # else:
            #     QtGui.QMessageBox.about(self, "The pixels must be a number")
            self.uni = unidad
            self.che2 = ch2
            self.che3 = ch3
            self.che4 = ch4
            self.che5 = ch5
            self.che6 = ch6
            self.che7 = ch7
            self.che8 = ch8
            self.che9 = ch9
            self.che10 = ch10
            # Se cierra el dialogo
            self.dialog.close()
        except:
            print("hola")
            self.dialog.close()


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Dialog = QtWidgets.QDialog()
    ui = Ui_Dialog1()
    ui.setupUi1(Dialog)
    Dialog.show()
    sys.exit(app.exec_())



SETTING_FILENAME = 'filename'
SETTING_RECENT_FILES = 'recentFiles'
SETTING_WIN_SIZE = 'window/size'
SETTING_WIN_POSE = 'window/position'
SETTING_WIN_GEOMETRY = 'window/geometry'
SETTING_LINE_COLOR = 'line/color'
SETTING_FILL_COLOR = 'fill/color'
SETTING_ADVANCE_MODE = 'advanced'
SETTING_WIN_STATE = 'window/state'
SETTING_SAVE_DIR = 'savedir'
SETTING_PAINT_LABEL = 'paintlabel'
SETTING_LAST_OPEN_DIR = 'lastOpenDir'
SETTING_AUTO_SAVE = 'autosave'
SETTING_SINGLE_CLASS = 'singleclass'
FORMAT_PASCALVOC='PascalVOC'
FORMAT_YOLO='YOLO'
SETTING_DRAW_SQUARE = 'draw/square'
DEFAULT_ENCODING = 'utf-8'



try:
    from PyQt5.QtGui import *
    from PyQt5.QtCore import *
    from PyQt5.QtWidgets import *
except ImportError:
    from PyQt4.QtGui import *
    from PyQt4.QtCore import *

from libs.utils import newIcon, labelValidator

BB = QDialogButtonBox


class ExcelDialog(QMainWindow):

    def __init__(self, text="Generate Excel", parent=None, listItem=None):
        super(ExcelDialog, self).__init__(parent)

        self.label = QLabel()
        self.label.setGeometry(QRect(20, 20, 431, 17))
        self.label.setObjectName("label")
        self.lineEdit = QLineEdit()
        self.lineEdit.setGeometry(QRect(20, 70, 113, 25))
        self.lineEdit.setObjectName("lineEdit")
        self.comboBox = QComboBox()
        self.comboBox.setGeometry(QRect(150, 70, 51, 25))
        self.comboBox.setObjectName("comboBox")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.lineEdit_2 = QLineEdit()
        self.lineEdit_2.setGeometry(QRect(250, 70, 113, 25))
        self.lineEdit_2.setObjectName("lineEdit_2")
        self.label_2 = QLabel()
        self.label_2.setGeometry(QRect(370, 70, 21, 17))
        self.label_2.setObjectName("label_2")
        self.line = QFrame()
        self.line.setGeometry(QRect(0, 110, 491, 20))
        self.line.setFrameShape(QFrame.HLine)
        self.line.setFrameShadow(QFrame.Sunken)
        self.line.setObjectName("line")
        self.label_3 = QLabel()
        self.label_3.setGeometry(QRect(20, 140, 391, 17))
        self.label_3.setObjectName("label_3")
        self.checkBox = QCheckBox()
        self.checkBox.setEnabled(False)
        self.checkBox.setGeometry(QRect(30, 180, 151, 23))
        self.checkBox.setChecked(True)
        self.checkBox.setObjectName("checkBox")
        self.checkBox_2 = QCheckBox()
        self.checkBox_2.setGeometry(QRect(30, 220, 151, 23))
        self.checkBox_2.setObjectName("checkBox_2")
        self.checkBox_3 = QCheckBox()
        self.checkBox_3.setGeometry(QRect(30, 260, 131, 23))
        self.checkBox_3.setObjectName("checkBox_3")
        self.checkBox_4 = QCheckBox()
        self.checkBox_4.setGeometry(QRect(250, 260, 131, 23))
        self.checkBox_4.setObjectName("checkBox_4")
        self.checkBox_5 = QCheckBox()
        self.checkBox_5.setGeometry(QRect(250, 220, 211, 23))
        self.checkBox_5.setObjectName("checkBox_5")
        self.checkBox_6 = QCheckBox()
        self.checkBox_6.setGeometry(QRect(250, 180, 221, 23))
        self.checkBox_6.setObjectName("checkBox_6")
        self.checkBox_7 = QCheckBox()
        self.checkBox_7.setGeometry(QRect(30, 360, 231, 23))
        self.checkBox_7.setObjectName("checkBox_7")
        self.checkBox_8 = QCheckBox()
        self.checkBox_8.setGeometry(QRect(30, 400, 171, 23))
        self.checkBox_8.setObjectName("checkBox_8")
        self.checkBox_9 = QCheckBox()
        self.checkBox_9.setGeometry(QRect(250, 360, 161, 23))
        self.checkBox_9.setObjectName("checkBox_9")
        self.checkBox_10 = QCheckBox()
        self.checkBox_10.setGeometry(QRect(250, 400, 231, 23))
        self.checkBox_10.setObjectName("checkBox_10")
        self.label_4 = QLabel()
        self.label_4.setGeometry(QRect(20, 330, 271, 20))
        font = QFont()
        font.setPointSize(8)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.line_2 = QFrame()
        self.line_2.setGeometry(QRect(0, 310, 491, 16))
        self.line_2.setFrameShape(QFrame.HLine)
        self.line_2.setFrameShadow(QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.pushButton = QPushButton()
        self.pushButton.setGeometry(QRect(258, 70, 61, 25))
        self.pushButton.setObjectName("push")

        self.retranslateUi()

    def retranslateUi(self):
        _translate = QCoreApplication.translate
        # Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.label.setText(_translate("Dialog", "Enter the scale, the unit and the corresponding pixels:"))
        self.comboBox.setItemText(0, _translate("Dialog", "cm"))
        self.comboBox.setItemText(1, _translate("Dialog", "mm"))
        self.comboBox.setItemText(2, _translate("Dialog", "µm"))
        self.label_2.setText(_translate("Dialog", "px"))
        self.label_3.setText(_translate("Dialog", "Select the excel columns:"))
        self.checkBox.setText(_translate("Dialog", "Name of the image"))
        self.checkBox_2.setText(_translate("Dialog", "Number os stomas"))
        self.checkBox_3.setText(_translate("Dialog", "Average height"))
        self.checkBox_4.setText(_translate("Dialog", "Width average"))
        self.checkBox_5.setText(_translate("Dialog", "Typical deviation of height"))
        self.checkBox_6.setText(_translate("Dialog", "Typical deviation of the width"))
        self.checkBox_7.setText(_translate("Dialog", "Number stomas per surface"))
        self.checkBox_8.setText(_translate("Dialog", "Area of ​​surface"))
        self.checkBox_9.setText(_translate("Dialog", "Stomas by surface"))
        self.checkBox_10.setText(_translate("Dialog", "Height/width of each stoma2"))
        self.pushButton.setText(_translate("Dialog", "PushButton"))

    def selectionchange(self, i):
        print("Items in the list are :")

        for count in range(self.cb.count()):
            print
            self.cb.itemText(count)
        print("Current index", i, "selection changed ", self.cb.currentText())

    def validate(self):
        try:
            if self.edit.text().trimmed():
                self.accept()
        except AttributeError:
            # PyQt5: AttributeError: 'str' object has no attribute 'trimmed'
            if self.edit.text().strip():
                self.accept()

    def postProcess(self):
        try:
            self.edit.setText(self.edit.text().trimmed())
        except AttributeError:
            # PyQt5: AttributeError: 'str' object has no attribute 'trimmed'
            self.edit.setText(self.edit.text())

    def popUp(self, text='', move=True):
        self.edit.setText(text)
        self.edit.setSelection(0, len(text))
        self.edit.setFocus(Qt.PopupFocusReason)
        if move:
            self.move(QCursor.pos())
        return self.edit.text() if self.exec_() else None

    def listItemClick(self, tQListWidgetItem):
        try:
            text = tQListWidgetItem.text().trimmed()
        except AttributeError:
            # PyQt5: AttributeError: 'str' object has no attribute 'trimmed'
            text = tQListWidgetItem.text().strip()
        self.edit.setText(text)

    def listItemDoubleClick(self, tQListWidgetItem):
        self.listItemClick(tQListWidgetItem)
        self.validate()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'detectPesos.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    genera = False
    def setupUi(self, Ui_Dialog):
        Ui_Dialog.setObjectName("Dialog")
        Ui_Dialog.resize(384, 236)
        self.dialog = Ui_Dialog
        self.buttonBox = QtWidgets.QDialogButtonBox(Ui_Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(30, 190, 341, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.label = QtWidgets.QLabel(Ui_Dialog)
        self.label.setGeometry(QtCore.QRect(26, 10, 311, 41))
        self.label.setObjectName("label")
        self.radioButton = QtWidgets.QRadioButton(Ui_Dialog)
        self.radioButton.setGeometry(QtCore.QRect(60, 60, 141, 23))
        self.radioButton.setChecked(True)
        self.radioButton.setObjectName("radioButton")
        self.radioButton_2 = QtWidgets.QRadioButton(Ui_Dialog)
        self.radioButton_2.setGeometry(QtCore.QRect(60, 100, 381, 23))
        self.radioButton_2.setObjectName("radioButton_2")
        self.lineEdit = QtWidgets.QLineEdit(Ui_Dialog)
        self.lineEdit.setEnabled(True)
        self.lineEdit.setGeometry(QtCore.QRect(110, 130, 113, 25))
        self.lineEdit.setAlignment(QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter)
        self.lineEdit.setObjectName("lineEdit")
        self.retranslateUi(Ui_Dialog)
        self.buttonBox.accepted.connect(self.actualizar)
        QtCore.QMetaObject.connectSlotsByName(Ui_Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.label.setText(_translate("Dialog", "What weights are you going to use to detect?"))
        self.radioButton.setText(_translate("Dialog", "Default weights"))
        self.radioButton_2.setText(_translate("Dialog", "Your own weights (Select the confidence)"))
        self.lineEdit.setText(_translate("Dialog", "0.4"))

    def actualizar(self):
        self.genera = True


        default = self.radioButton.isChecked()
        our = self.radioButton_2.isChecked()
        le1 = self.lineEdit.text()
        self.default_1 = default
        self.our_1 = our
        self.le_1 = le1
        self.dialog.close()



if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Dialog = QtWidgets.QDialog()
    ui = Ui_Dialog()
    ui.setupUi(Dialog)
    Dialog.show()
    sys.exit(app.exec_())



import cv2 as cv
import numpy as np
import xml.etree.ElementTree as ET
from xml.dom import minidom
from imutils import paths
import os
from tqdm import tqdm


confThreshold = 0.4  # Confidence threshold
nmsThreshold = 0.4  # Non-maximum suppression threshold
inpWidth = 416  # Width of network's input image
inpHeight = 416  # Height of network's input image


# Get the names of the output layers
def getOutputsNames(net):
    # Get the names of all the layers in the network
    layersNames = net.getLayerNames()
    # Get the names of the output layers, i.e. the layers with unconnected outputs
    return [layersNames[i[0] - 1] for i in net.getUnconnectedOutLayers()]


# Remove the bounding boxes with low confidence using non-maxima suppression
def postprocess(frame, outs, conf):
    frameHeight = frame.shape[0]
    frameWidth = frame.shape[1]

    classIds = []
    confidences = []
    boxes = []
    # Scan through all the bounding boxes output from the network and keep only the
    # ones with high confidence scores. Assign the box's class label as the class with the highest score.
    classIds = []
    confidences = []
    boxes = []
    for out in outs:
        for detection in out:
            scores = detection[5:]
            classId = np.argmax(scores)
            confidence = scores[classId]
            if confidence > conf:
                center_x = int(detection[0] * frameWidth)
                center_y = int(detection[1] * frameHeight)
                width = int(detection[2] * frameWidth)
                height = int(detection[3] * frameHeight)
                left = int(center_x - width / 2)
                top = int(center_y - height / 2)
                classIds.append(classId)
                confidences.append(float(confidence))
                boxes.append([left, top, width, height])

    # Perform non maximum suppression to eliminate redundant overlapping boxes with
    # lower confidences.
    newboxes = []
    newconfidences = []
    newclassIds = []
    indices = cv.dnn.NMSBoxes(boxes, confidences, conf, nmsThreshold)
    for i in indices:
        i = i[0]
        newboxes.append(boxes[i])
        newconfidences.append(confidences[i])
        newclassIds.append(classIds[i])
    return newboxes, newconfidences, newclassIds


class DownloadProgressBar(tqdm):
    def update_to(self, b=1, bsize=1, tsize=None):
        if tsize is not None:
            self.total = tsize
        self.update(b * bsize - self.n)


def prettify(elem):
    """Return a pretty-printed XML string for the Element.
    """
    rough_string = ET.tostring(elem, 'utf-8')
    reparsed = minidom.parseString(rough_string)
    return reparsed.toprettyxml(indent="  ")


def generateXML(filename, outputPath, w, h, d, boxes, confidences, classIds, classes):
    top = ET.Element('annotation')
    childFolder = ET.SubElement(top, 'folder')
    childFolder.text = 'images'
    childFilename = ET.SubElement(top, 'filename')
    childFilename.text = filename[0:filename.rfind(".")]
    childPath = ET.SubElement(top, 'path')
    childPath.text = outputPath + "/" + filename
    childSource = ET.SubElement(top, 'source')
    childDatabase = ET.SubElement(childSource, 'database')
    childDatabase.text = 'Unknown'
    childSize = ET.SubElement(top, 'size')
    childWidth = ET.SubElement(childSize, 'width')
    childWidth.text = str(w)
    childHeight = ET.SubElement(childSize, 'height')
    childHeight.text = str(h)
    childDepth = ET.SubElement(childSize, 'depth')
    childDepth.text = str(d)
    childSegmented = ET.SubElement(top, 'segmented')
    childSegmented.text = str(0)
    for box, con, categoryID in zip(boxes, confidences, classIds):
        category = classes[categoryID]
        (x, y, wb, hb) = box
        childObject = ET.SubElement(top, 'object')
        childName = ET.SubElement(childObject, 'name')
        childName.text = category
        childPose = ET.SubElement(childObject, 'pose')
        childPose.text = 'Unspecified'
        childTruncated = ET.SubElement(childObject, 'truncated')
        childTruncated.text = '0'
        childDifficult = ET.SubElement(childObject, 'difficult')
        childDifficult.text = '0'
        childConfidence = ET.SubElement(childObject, 'confidence')
        childConfidence.text = str(con)
        childBndBox = ET.SubElement(childObject, 'bndbox')
        childXmin = ET.SubElement(childBndBox, 'xmin')
        childXmin.text = str(x)
        childYmin = ET.SubElement(childBndBox, 'ymin')
        childYmin.text = str(y)
        childXmax = ET.SubElement(childBndBox, 'xmax')
        childXmax.text = str(x + wb)
        childYmax = ET.SubElement(childBndBox, 'ymax')
        childYmax.text = str(y + hb)
    return prettify(top)


def mainImage(imagePath):
    generateXMLFromImage(imagePath)


def mainDataset(imagesPath, outputDataset, conf,pathPesos, fichNames, fichCfg):
    # Give the configuration and weight files for the model and
    # load the network using them.
    if os.path.exists(outputDataset) == False:
        os.mkdir(outputDataset)
    dirPath = os.path.dirname(os.path.realpath(__file__))
    classes = None
    with open(fichNames, 'rt') as f:
        classes = f.read().rstrip('\n').split('\n')


    # Invocamos a la funcion con dichos parametros y mostramos el resultado por pantalla
    images = list(paths.list_files(imagesPath, validExts=(".jpg", ".jpeg", ".png", ".bmp", ".tiff", ".tif")))
    # for peso in modelWeights:
    net = cv.dnn.readNetFromDarknet(fichCfg, pathPesos)  # peso)
    net.setPreferableBackend(cv.dnn.DNN_BACKEND_OPENCV)
    net.setPreferableTarget(cv.dnn.DNN_TARGET_CPU)
    # nomPeso = os.path.basename( pathPesos)#peso)
    # nombre = os.path.splitext(nomPeso)[0]
    for image in images:
        generateXMLFromImage(image, outputDataset, net, classes, conf)  # +'/'+nombre, net)


def generateXMLFromImage(imagePath, output, net, classes, conf):
    im = cv.VideoCapture(imagePath)
    hasFrame, frame = im.read()
    blob = cv.dnn.blobFromImage(frame, 1 / 255, (inpWidth, inpHeight), [0, 0, 0], 1, crop=False)

    if os.path.exists(output) == False:
        os.mkdir(output)
    # Sets the input to the network
    net.setInput(blob)
    # Runs the forward pass to get output of the output layers
    outs = net.forward(getOutputsNames(net))

    # Remove the bounding boxes with low confidence
    boxes, confidences, classIds = postprocess(frame, outs, conf)
    wI, hI, d = frame.shape
    filename = os.path.basename(imagePath)
    file = open(output + '/' + os.path.splitext(filename)[0] + ".xml", "w")
    file.write(generateXML(imagePath[0:imagePath.rfind(".")], "", wI, hI, d, boxes, confidences, classIds, classes))
    file.close()